@@ -1,9 +1,9 @@
 import asyncio
 import json
 import logging
-import os
 import re
 import sys
+from pathlib import Path
 from typing import Dict, List, Optional
 
 from clairvoyance import graphql, oracle
@@ -22,6 +22,7 @@ def setup_context(
     proxy: Optional[str] = None,
     max_retries: Optional[int] = None,
     backoff: Optional[int] = None,
+    disable_ssl_verify: Optional[bool] = None,
 ) -> None:
     """Initialize objects and freeze them into the context."""
 
@@ -33,12 +34,13 @@ def setup_context(
         proxy=proxy,
         max_retries=max_retries,
         backoff=backoff,
+        disable_ssl_verify=disable_ssl_verify,
     )
     logger_ctx.set(logger)
 
 
 def load_default_wordlist() -> List[str]:
-    wl = os.path.join(os.path.dirname(__file__), 'wordlist.txt')
+    wl = Path(__file__).parent / 'wordlist.txt'
     with open(wl, 'r', encoding='utf-8') as f:
         return [w.strip() for w in f.readlines() if w.strip()]
 
@@ -55,6 +57,7 @@ async def blind_introspection(
     proxy: Optional[str] = None,
     max_retries: Optional[int] = None,
     backoff: Optional[int] = None,
+    disable_ssl_verify: Optional[bool] = None,
 ) -> str:
     wordlist = wordlist or load_default_wordlist()
     assert wordlist, 'No wordlist provided'
@@ -67,6 +70,7 @@ async def blind_introspection(
         proxy=proxy,
         max_retries=max_retries,
         backoff=backoff,
+        disable_ssl_verify=disable_ssl_verify,
     )
 
     logger.info(f'Starting blind introspection on {url}...')
@@ -78,7 +82,10 @@ async def blind_introspection(
 
     input_document = input_document or 'query { FUZZ }'
     ignored = set(e.value for e in GraphQLPrimitive)
+    iterations = 1
     while True:
+        logger.info(f'Iteration {iterations}')
+        iterations += 1
         schema = await oracle.clairvoyance(
             wordlist,
             input_document=input_document,
@@ -145,5 +152,6 @@ def cli(argv: Optional[List[str]] = None) -> None:
             proxy=args.proxy,
             max_retries=args.max_retries,
             backoff=args.backoff,
+            disable_ssl_verify=args.no_ssl,
         )
     )
