@@ -2,6 +2,7 @@
 
 import asyncio
 import re
+import sys
 import time
 from typing import Any, Dict, List, Optional, Set, Tuple
 
@@ -9,6 +10,7 @@ from clairvoyance import graphql
 from clairvoyance.entities import GraphQLPrimitive
 from clairvoyance.entities.context import client, config, log
 from clairvoyance.entities.oracle import FuzzingContext
+from clairvoyance.utils import track
 
 # yapf: disable
 
@@ -199,8 +201,8 @@ async def probe_valid_fields(
 
     # Process results
     valid_fields = set()
-    results = await asyncio.gather(*tasks)
-    for result in results:
+    for task in track(asyncio.as_completed(tasks), description=f'Sending {len(tasks)} fields', total=len(tasks)):
+        result = await task
         valid_fields.update(result)
 
     return valid_fields
@@ -459,7 +461,8 @@ async def probe_typename(input_document: str) -> str:
 
     response = await client().post(document=document)
     if 'errors' not in response:
-        raise Exception(f'Unable to get typename from {document}')
+        log().debug(f'Unable to get typename from {document}')
+        sys.exit(1)
 
     errors = response['errors']
 
@@ -473,7 +476,7 @@ async def probe_typename(input_document: str) -> str:
             break
 
     if not match:
-        raise Exception(f'Unkwon error in `probe_typename`: "{errors}" does not match any known regexes.')
+        log().debug(f'Unkwon error in `probe_typename`: "{errors}" does not match any known regexes.')
 
     return (match.group('typename').replace('[', '').replace(']', '').replace('!', ''))
 
@@ -490,7 +493,7 @@ async def fetch_root_typenames() -> Dict[str, Optional[str]]:
         'subscriptionType': None,
     }
 
-    for name, document in documents.items():
+    for name, document in track(documents.items(), description='Fetching root typenames'):
         response = await client().post(document=document)
 
         data = response.get('data', {})
@@ -574,8 +577,8 @@ async def clairvoyance(
             typename,
         )))
 
-    results = await asyncio.gather(*tasks)
-    for (field, args) in results:
+    for task in track(asyncio.as_completed(tasks), description=f'Processing {len(tasks)} responses', total=len(tasks)):
+        field, args = await task
         for arg in args:
             schema.add_type(arg.type.name, 'INPUT_OBJECT')
         schema.types[typename].fields.append(field)
